﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.DragDrop;
using System.Collections.ObjectModel;
using System.Collections;

namespace DragDropToUserControlWPF
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private ObservableCollection<MyViewModel> items = new ObservableCollection<MyViewModel>();

		public MainWindow()
		{
			InitializeComponent();

			for (int i = 0; i < 30; i++)
			{
				this.items.Add(new MyViewModel() { Name = "Item" + i, Id = i });
			}

			this.ListBox.ItemsSource = this.items;

			DragDropManager.AddDragInitializeHandler(this.ListBox, OnDragInitialize);
			DragDropManager.AddGiveFeedbackHandler(this.ListBox, OnGiveFeedback);
			DragDropManager.AddDragDropCompletedHandler(this.ListBox, OnDragCompleted);
			DragDropManager.AddDropHandler(this.ListBox, OnDrop);

			DragDropManager.AddDropHandler(this.MyControl, OnMyControlDrop, true);
			DragDropManager.AddPreviewDropHandler(this.MyControl, OnMyControlPreviewDrop);
		}

		private void OnDragInitialize(object sender, DragInitializeEventArgs e)
		{
			e.AllowedEffects = DragDropEffects.All;
			var data = ((FrameworkElement)e.OriginalSource).DataContext;
			e.DragVisual = new DragVisual()
			{
				Content = data,
				ContentTemplate = this.Resources["DragTemplate"] as DataTemplate
			};

			DataObject dataObject = new DataObject();
			dataObject.SetText(data.ToString());
			dataObject.SetData("DragData", data);
			dataObject.SetData("Text", data.ToString());

			e.Data = dataObject;
		}

		private void OnGiveFeedback(object sender, Telerik.Windows.DragDrop.GiveFeedbackEventArgs args)
		{
			args.SetCursor(Cursors.Arrow);
			args.Handled = true;
		}

		private void OnDrop(object sender, Telerik.Windows.DragDrop.DragEventArgs args)
		{
			var item = (args.Data as DataObject).GetData("DragData") as MyViewModel;

			((IList)(sender as ListBox).ItemsSource).Add(item);
		}

		public void OnDragCompleted(object sender, Telerik.Windows.DragDrop.DragDropCompletedEventArgs args)
		{
			var item = (args.Data as DataObject).GetData("DragData") as MyViewModel;

			((IList)(sender as ListBox).ItemsSource).Remove(item);
		}

		private void OnMyControlDrop(object sender, Telerik.Windows.DragDrop.DragEventArgs args)
		{
			
		}

		private void OnMyControlPreviewDrop(object sender, Telerik.Windows.DragDrop.DragEventArgs args)
		{

		}
	}
}
